path to Tabix-indexed bgzipped TSV of CADD as distributed at krishna.gs.washington.edu on
1 April 2014
Value
GRanges instance with additional fields as obtained in the CADD resource
Details
joins CADD fields at addresses that match query; the CADD fields for
query ranges that are not
matched are set to NA
References
M Kircher, DM Witten, P Jain, BJ O'Roak, GM Cooper, J Shendure,
A general framework for estimating the relative pathogenicity of human genetic variants,
Nature Genetics Feb 2014, PMID 24487276